@@ -40,6 +40,11 @@ MainWindow::MainWindow(QWidget *parent, QStringList args) :
     ui->setupUi(this);
     shell = new Cmd(this);
     this->args = args;
+
+    QFont font("monospace");
+    font.setStyleHint(QFont::Monospace);
+    ui->outputBox->setFont(font);
+
     connect(shell, &Cmd::started, this, &MainWindow::procStart);
     connect(shell, &Cmd::finished, this, &MainWindow::procDone);
     connect(shell, &Cmd::runTime, this, &MainWindow::progress);
@@ -53,9 +58,19 @@ MainWindow::MainWindow(QWidget *parent, QStringList args) :
 
     version = getVersion("iso-snapshot");
     live = isLive();
-
+    users = listUsers();
     i686 = isi686();
     debian_version = getDebianVersion();
+
+    englishDirs = {
+        {"DOCUMENTS", "Documents"},
+        {"DOWNLOAD", "Downloads"},
+        {"DESKTOP", "Desktop"},
+        {"MUSIC", "Music"},
+        {"PICTURES", "Pictures"},
+        {"VIDEOS", "Videos"},
+    };
+
     setup();
     reset_accounts = false;
     if (args.contains("--monthly") || args.contains("-m")) {
@@ -94,7 +109,7 @@ void MainWindow::loadSettings()
     force_installer = settings.value("force_installer", "true").toBool();
     ui->lineEditName->setText(getFilename());
     QString prev; //previous arg
-    foreach (QString arg, args) {
+    foreach (const QString &arg, args) {
         if (prev == "--monthly" || prev == "-m") {
             QString name = shell->getOutput("cat /etc/antix-version | cut -f1 -d' '");
             qDebug() << "MONTH" << arg;
@@ -187,6 +202,33 @@ QString MainWindow::getSnapshotSize()
     return "0";
 }
 
+// return the XDG User Directory for each user with different localizations than English
+QString MainWindow::getXdgUserDirs(const QString& folder)
+{
+    QString result = "";
+
+    foreach (const QString &user, users) {
+        if (shell->run("su " + user + " -c \"xdg-user-dir " + folder + "\"") == 0) {
+            QString dir = shell->getOutput();
+            if (englishDirs.value(folder) == dir.section("/", -1) || dir == "/home/" + user || dir.isEmpty()) { // skip if English name or of return folder is the home folder (if XDG-USER-DIR not defined)
+                continue;
+            }
+            if (dir.startsWith("/")) {
+                dir.remove(0, 1); // remove training slash
+            }
+            (folder == "DESKTOP") ? dir.append("/!(minstall.desktop)") : dir.append("/*");
+            (result.isEmpty()) ? result.append("\" \"" + dir) : result.append(" \"" + dir);
+        }
+    }
+    return result;
+}
+
+// return a list of users that have folders in /home
+QStringList MainWindow::listUsers()
+{
+    return shell->getOutput("ls /home | grep -v lost+found | grep -v snapshot | grep [a-zA-Z0-9]").split("\n");
+}
+
 // List used space
 void MainWindow::listUsedSpace()
 {
@@ -333,7 +375,7 @@ void MainWindow::copyNewIso()
     }
 
     replaceMenuStrings();
-    shell->run("/usr/share/packageinstaller/scripts/make-efi-img " + work_dir + "/iso-template/");
+    shell->run("/usr/share/iso-snapshot-antix/scripts/make-efi-img " + work_dir + "/iso-template/");
 
     makeMd5sum(work_dir + "/iso-template/antiX", "vmlinuz");
 
@@ -405,14 +447,14 @@ void MainWindow::replaceMenuStrings() {
 void MainWindow::copyModules(QString to, QString kernel)
 {
     QString kernel586 = "3.16.0-4-586";
-    QString cmd = QString("/usr/share/packageinstaller/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel);
+    QString cmd = QString("/usr/share/iso-snapshot-antix/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel);
     shell->run(cmd);
     // copy 586 modules for the non-PAE kernel
     if (i686 && debian_version < 9) {  // Not applicable for Stretch (MX17) or more
-        QString cmd = QString("/usr/share/mx-packageinstaller/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel586);
+        QString cmd = QString("/usr/share/iso-snapshot-antix/scripts/copy-initrd-modules -t=\"%1\" -k=\"%2\"").arg(to).arg(kernel586);
         shell->run(cmd);
     }
-    cmd = QString("/usr/share/packageinstaller/scripts/copy-initrd-programs --to=\"%1\"").arg(to);
+    cmd = QString("/usr/share/iso-snapshot-antix/scripts/copy-initrd-programs --to=\"%1\"").arg(to);
     shell->run(cmd);
 }
 
@@ -516,11 +558,12 @@ void MainWindow::setupEnv()
     if (reset_accounts) {
         shell->run("installed-to-live -b /.bind-root start " + bind_boot + "empty=/home general version-file read-only");
     } else {
-        // copy antixsources.desktop to Desktop on all accounts
-        system("echo /home/*/Desktop | xargs -n1 cp /usr/share/applications/antix/antixsources.desktop 2>/dev/null");
-        system("chmod +x /home/*/Desktop/antixsources.desktop");
-        shell->run("installed-to-live -b /.bind-root start bind=/home" + bind_boot_too + " live-files version-file adjtime read-only");
+        if (force_installer == true) {  // copy minstall.desktop to Desktop on all accounts
+            shell->run("echo /home/*/Desktop | xargs -n1 cp /usr/share/applications/minstall.desktop 2>/dev/null");
+            shell->run("chmod +x /home/*/Desktop/minstall.desktop");
         }
+        shell->run("installed-to-live -b /.bind-root start bind=/home" + bind_boot_too + " live-files version-file adjtime read-only");
+    }
 }
 
 int MainWindow::getDebianVersion()
@@ -585,6 +628,11 @@ bool MainWindow::createIso(QString filename)
         makeMd5sum(snapshot_dir.absolutePath(), filename);
         makeSha512sum(snapshot_dir.absolutePath(), filename);
     }
+
+    if (shell->getError() == 0) {
+        ui->outputBox->insertPlainText("\n" + tr("Snapshot completed sucessfully!") + "\n");
+        ui->outputBox->insertPlainText(tr("Thanks for using it, run live-usb-maker next!"));
+    }
     disableOutput();
     return true;
 }
@@ -622,7 +670,7 @@ void MainWindow::cleanUp()
     ui->outputLabel->setText(tr("Cleaning..."));
     system("pkill mksquashfs; pkill md5sum");
     QDir::setCurrent("/");
-    system("installed-to-live cleanup");
+    system("[ -f /tmp/installed-to-live/cleanup.conf ] && installed-to-live cleanup");
 
     // checks if work_dir looks OK
     if (work_dir.contains("/iso-snapshot")) {
@@ -670,6 +718,23 @@ void MainWindow::displayDoc(QString url)
     shell->run(cmd);
 }
 
+// check if compression is available in the kernel (lz4, lzo, xz)
+bool MainWindow::checkCompression()
+{
+    if (shell->run("[ -f /boot/config-$(uname -r) ]") != 0) { // return true if cannot check config file
+        return true;
+    }
+    if (mksq_opt.contains("lz4")) {
+        return (shell->run("grep ^CONFIG_SQUASHFS_LZ4=y /boot/config-$(uname -r)") == 0);
+    } else if (mksq_opt.contains("xz")) {
+        return (shell->run("grep ^CONFIG_SQUASHFS_XZ=y /boot/config-$(uname -r)") == 0);
+    } else if (mksq_opt.contains("lzo")) {
+        return (shell->run("grep ^CONFIG_SQUASHFS_LZO=y /boot/config-$(uname -r)") == 0);
+    } else {
+        return true;
+    }
+}
+
 //// sync process events ////
 void MainWindow::procStart()
 {
@@ -742,6 +807,11 @@ void MainWindow::on_buttonNext_clicked()
 
     // on settings page
     } else if (ui->stackedWidget->currentWidget() == ui->settingsPage) {
+        if (!checkCompression()) {
+            QMessageBox::critical(this, tr("Error"),
+                    tr("Current kernel doesn't support selected compression algorithm, please edit the configuration file and select a different algorithm."));
+            return;
+        }
 
         int ans = QMessageBox::question(this, tr("Final chance"),
                               tr("Snapshot now has all the information it needs to create an ISO from your running system.") + "\n\n" +
@@ -808,13 +878,7 @@ void MainWindow::on_buttonEditExclude_clicked()
 
 void MainWindow::on_excludeDocuments_toggled(bool checked)
 {
-    QString user = shell->getOutput("logname");
-    QString xdg_user_dir = shell->getOutput("su " + user + " -c \"xdg-user-dir DOCUMENTS\"") + "/*";
-    xdg_user_dir.replace(user, "*");
-    if (xdg_user_dir.startsWith("/")) {
-        xdg_user_dir.remove(0, 1); // remove training slash
-    }
-    QString exclusion = "/home/*/Documents/*\" \"" + xdg_user_dir;
+    QString exclusion = "/home/*/Documents/*" + getXdgUserDirs("DOCUMENTS");
     addRemoveExclusion(checked, exclusion);
     if (!checked) {
         ui->excludeAll->setChecked(false);
@@ -823,13 +887,7 @@ void MainWindow::on_excludeDocuments_toggled(bool checked)
 
 void MainWindow::on_excludeDownloads_toggled(bool checked)
 {
-    QString user = shell->getOutput("logname");
-    QString xdg_user_dir = shell->getOutput("su " + user + " -c \"xdg-user-dir DOWNLOAD\"") + "/*";
-    xdg_user_dir.replace(user, "*");
-    if (xdg_user_dir.startsWith("/")) {
-        xdg_user_dir.remove(0, 1); // remove training slash
-    }
-    QString exclusion = "/home/*/Downloads/*\" \"" + xdg_user_dir;
+    QString exclusion = "/home/*/Downloads/*" + getXdgUserDirs("DOWNLOAD");
     addRemoveExclusion(checked, exclusion);
     if (!checked) {
         ui->excludeAll->setChecked(false);
@@ -838,13 +896,7 @@ void MainWindow::on_excludeDownloads_toggled(bool checked)
 
 void MainWindow::on_excludePictures_toggled(bool checked)
 {
-    QString user = shell->getOutput("logname");
-    QString xdg_user_dir = shell->getOutput("su " + user + " -c \"xdg-user-dir PICTURES\"") + "/*";
-    xdg_user_dir.replace(user, "*");
-    if (xdg_user_dir.startsWith("/")) {
-        xdg_user_dir.remove(0, 1); // remove training slash
-    }
-    QString exclusion = "/home/*/Pictures/*\" \"" + xdg_user_dir;
+    QString exclusion = "/home/*/Pictures/*" + getXdgUserDirs("PICTURES");
     addRemoveExclusion(checked, exclusion);
     if (!checked) {
         ui->excludeAll->setChecked(false);
@@ -853,13 +905,7 @@ void MainWindow::on_excludePictures_toggled(bool checked)
 
 void MainWindow::on_excludeMusic_toggled(bool checked)
 {
-    QString user = shell->getOutput("logname");
-    QString xdg_user_dir = shell->getOutput("su " + user + " -c \"xdg-user-dir MUSIC\"") + "/*";
-    xdg_user_dir.replace(user, "*");
-    if (xdg_user_dir.startsWith("/")) {
-        xdg_user_dir.remove(0, 1); // remove training slash
-    }
-    QString exclusion = "/home/*/Music/*\" \"" + xdg_user_dir;
+    QString exclusion = "/home/*/Music/*" + getXdgUserDirs("MUSIC");
     addRemoveExclusion(checked, exclusion);
     if (!checked) {
         ui->excludeAll->setChecked(false);
@@ -868,13 +914,7 @@ void MainWindow::on_excludeMusic_toggled(bool checked)
 
 void MainWindow::on_excludeVideos_toggled(bool checked)
 {
-    QString user = shell->getOutput("logname");
-    QString xdg_user_dir = shell->getOutput("su " + user + " -c \"xdg-user-dir VIDEOS\"") + "/*";
-    xdg_user_dir.replace(user, "*");
-    if (xdg_user_dir.startsWith("/")) {
-        xdg_user_dir.remove(0, 1); // remove training slash
-    }
-    QString exclusion = "/home/*/Videos/*\" \"" + xdg_user_dir;
+    QString exclusion = "/home/*/Videos/*" + getXdgUserDirs("VIDEOS");
     addRemoveExclusion(checked, exclusion);
     if (!checked) {
         ui->excludeAll->setChecked(false);
@@ -883,13 +923,7 @@ void MainWindow::on_excludeVideos_toggled(bool checked)
 
 void MainWindow::on_excludeDesktop_toggled(bool checked)
 {
-    QString user = shell->getOutput("logname");
-    QString xdg_user_dir = shell->getOutput("su " + user + " -c \"xdg-user-dir DESKTOP\"");
-    xdg_user_dir.replace(user, "*");
-    if (xdg_user_dir.startsWith("/")) {
-        xdg_user_dir.remove(0, 1); // remove training slash
-    }
-    QString exclusion = "/home/*/Desktop/!(minstall.desktop)\" \"" + xdg_user_dir + "/!(minstall.desktop)";
+    QString exclusion = "/home/*/Desktop/!(minstall.desktop)" + getXdgUserDirs("DESKTOP");
     addRemoveExclusion(checked, exclusion);
     if (!checked) {
         ui->excludeAll->setChecked(false);
@@ -967,7 +1001,7 @@ void MainWindow::on_buttonHelp_clicked()
     QString url = "https://mxlinux.org/wiki/help-files/help-mx-save-system-iso-snapshot";
 
     if (lang.startsWith("fr")) {
-        url = "https://mxlinux.org/wiki/help-files/help-mx-instantan%C3%A9";
+        url = "https://mxlinux.org/french-wiki/help-files-fr/help-mx-instantane";
     }
     displayDoc(url);
 }
